==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/SAPDB/Trace/Trace_Slot.hpp <==
/*!**************************************************************************

  module      : Trace_Slot.hpp

  -------------------------------------------------------------------------

  responsible : TorstenS

  special area:
  description : Implementation of Kernel VTrace

  last changed: 2000-11-27  18:15
  see also    :

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef TRACE_SLOT_HPP
#define TRACE_SLOT_HPP



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"   // PASCAL: SP_basic_constants_and_types
#include "ggg00.h"   // PASCAL: GG_kernel_constants_and_types
#include "heo761.h"  // RTE   : InterlockedCounter
#include "heo76.h"	 // RTE   : Spinlocks

#include "SAPDB/Trace/Trace_DevSpace.hpp"
#include "SAPDB/Trace/Trace_Page.hpp"
#include "SAPDB/Trace/Trace_Types.hpp"


/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/


/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/


/*===========================================================================*
 *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
 *===========================================================================*/


class Trace_Slot
{
public:
	
	Trace_Slot( tsp00_Int4 UKTId );
	
	bool Initialize();

	static tsp00_Int4 GetSize();

	void Flush( 
		tsp00_TaskId	TaskId,
		Trace_DevSpace	&DevSpace );

    void Insert(
        tgg00_TransContext	                    &Trans,
        tsp00_Int4                              UKTId,
        Trace_IBaseEntry	                    &Entry,
        ceo761InterlockedCounter<Trace_SeqNo>   &SeqNoGenerator );

    void InsertLarge(
        tgg00_TransContext                      &Trans,
        tsp00_Int4                              UKTId,
        Trace_ILargeEntry                       &Entry,
        ceo761InterlockedCounter<Trace_SeqNo>   &SeqNoGenerator );

	void ReInitialization();
    
private:
    
    void InsertIntoTracePage( Trace_IFullEntry &FullEntry );

private:

	tsp00_Int4			m_UKTId;
	tsp00_Int4			m_NumPages;
    tsp00_Int4          m_UsableSize;
	tsp00_Int4			m_PageListOffset;
	Trace_PageNo		m_PageNo;
	tsp00_PageAddr		m_pPageList;
	ceo76Spinlock		m_SpinLock;
	Trace_Page			m_Page;
};

typedef Trace_Slot* Trace_SlotPtr;

/*===========================================================================*
 *  IMPLEMENTATION OF METHODS                                                *
 *===========================================================================*/

inline tsp00_Int4 
Trace_Slot::GetSize()
{
#   ifdef BIT64
    return( ALIGN_8BYTE_EO00( sizeof( Trace_Slot )));
#   else
    return( ALIGN_4BYTE_EO00( sizeof( Trace_Slot )));
#	endif
};
	
#endif  /* TRACE_SLOT_HPP */

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/SAPDB/Trace/Trace_Slot.hpp <==
/*!**************************************************************************

  module      : Trace_Slot.hpp

  -------------------------------------------------------------------------

  responsible : TorstenS

  special area:
  description : Implementation of Kernel VTrace

  last changed: 2000-11-27  18:15
  see also    :

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef TRACE_SLOT_HPP
#define TRACE_SLOT_HPP



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"   // PASCAL: SP_basic_constants_and_types
#include "ggg00.h"   // PASCAL: GG_kernel_constants_and_types

#include "SAPDBCommon/SAPDB_Types.hpp"
#include "RunTime/Synchronisation/RTESync_InterlockedCounter.hpp"
#include "RunTime/Synchronisation/RTESync_NamedSpinlock.hpp"
#include "Trace/Trace_DevSpace.hpp"
#include "Trace/Trace_Page.hpp"
#include "Trace/Trace_Types.hpp"


/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/


/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/


/*===========================================================================*
 *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
 *===========================================================================*/


class Trace_Slot
{
public:
    
    Trace_Slot();
    
    bool Initialize( SAPDB_Int4 UKTId );

    void Flush( 
        tsp00_TaskId    TaskId,
        Trace_DevSpace  &DevSpace );

    void Insert(
        tgg00_TransContext                      &Trans,
        SAPDB_Int4                              UKTId,
        Trace_IBaseEntry                        &Entry,
        RTESync_InterlockedCounter<Trace_SeqNo> &SeqNoGenerator );

    void InsertLarge(
        tgg00_TransContext                      &Trans,
        SAPDB_Int4                              UKTId,
        Trace_ILargeEntry                       &Entry,
        RTESync_InterlockedCounter<Trace_SeqNo> &SeqNoGenerator );

    void ReInitialization();
    
private:
    
    void InsertIntoTracePage( Trace_IFullEntry &FullEntry );

private:

    SAPDB_Int4              m_UKTId;
    SAPDB_Int4              m_NumPages;
    SAPDB_Int4              m_UsableSize;
    SAPDB_Int4              m_PageListOffset;
    Trace_PageNo            m_PageNo;
    tsp00_PageAddr          m_pPageList;
    RTESync_NamedSpinlock   m_SpinLock;
    Trace_Page              m_Page;
};

typedef Trace_Slot* Trace_SlotPtr;

/*===========================================================================*
 *  IMPLEMENTATION OF METHODS                                                *
 *===========================================================================*/
    
#endif  /* TRACE_SLOT_HPP */
